# Foo

## Living Standard, 1 January 1970

This version:
  http://example.com/foo
Editor:
  Example Editor

COPYRIGHT GOES HERE

## Abstract

Testing custom CSS Lexer number formats

    element { property: 0; property: 10; }
    element { property: -1; property: +2; property: -11; property: +12; }

    element { property: 0em; property: 10em; }
    element { property: -1ex; property: +2%; property: -11ex; property: +12%; }

    element { property: .1; property: .12; property: 0.1; property: 0.12; }
    element { property: -.2; property: +.3; property: -.34; property: +.56; }
    element { property: -0.2; property: +0.3; property: -0.34; property: +0.56; }

    element { property: .1em; property: .12%; property: 0.1em; property: 0.12%; }
    element { property: -.2em; property: +.3%; property: -.34em; property: +.56%; }
    element { property: -0.2em; property: +0.3%; property: -0.34em; property: +0.56%; }

    element { property: 1e2; property: 10e20; }
    element { property: -1e2; property: +1e2; property: 1e-2; property: 1e+2; }
    element { property: -10e20; property: +10e20; property: 10e-20; property: 10e+20; }
    element { property: -1e-2; property: -1e+2; property: +1e-2; property: +1e+2; }
    element { property: -10e-20; property: -10e+20; property: +10e-20; property: +10e+20; }

    element { property: 1e2vi; property: 10e20ex;}
    element { property: -1e2vb; property: +1e2vmin; property: 1e-2vmax; property: 1e+2em; }
    element { property: -10e20ch; property: +10e20ic; property: 10e-20rem; property: 10e+20lh; }
    element { property: -1e-2rlh; property: -1e+2vw; property: +1e-2vh; property: +1e+2vi; }
    element { property: -10e-20vb; property: -10e+20vmin; property: +10e-20vmax; property: +10e+20%; }

    element { property: 1.0e2.0; property: 1.0e2.0ex;}
    element { property: -1.0e2.0; property: +1.0e2.0; property: 1.0e-2.0; property: 1.0e+2.0; }
    element { property: -1.0e-2.0; property: -1.0e+2.0; property: +1.0e-2.0; property: +1.0e+2.0; }
    element { property: -1.0e2.0ch; property: +1.0e2.0ic; property: 1.0e-2.0rem; property: 1.0e+2.0lh; }
    element { property: -1.0e-2.0vb; property: -1.0e+2.0vmin; property: +1.0e-2.0vmax; property: +1.0e+2.0%; }

    element { property: .1e2.0; property: .1e2.0ex; }
    element { property: -.1e2.0; property: +.1e2.0; property: .1e-.2; property: .1e+.2; }
    element { property: -.1e-2.0; property: -.1e+.20; property: +.1e-.2; property: +.1e+.2; }
    element { property: -.1e2.0ch; property: +.3e.2ic; property: .22e-.12rem; property: .1e+.2lh; }
    element { property: -.1e-2.0vb; property: -.1e+.2vmin; property: +.2e-.1vmax; property: +.1e+.2%; }

    element { property: 10.00e20.00; property: 11.01e12.10ex; }
    element { property: -11.01e21.01; property: +12.02e22.02; property: 12.02e-22.02; property: 31.03e+23.03; }
    element { property: -14.40e-24.04; property: -15.50e+52.50; property: +61.60e-62.60; property: +71.70e+28.08; }
    element { property: -11.10e21.10ch; property: +11.10e21.10ic; property: 11.10e-121.10rem; property: 11.10e+22.330lh; }
    element { property: -12.30e-223.10vb; property: -11.10e+21.10vmin; property: +11.10e-12.10vmax; property: +11.10e+21.10%; }